<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Glavno okno</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Strojna zadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Prilagoditve</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Zaslon</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Končaj</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="56"/>
        <location filename="../defaultlook.cpp" line="81"/>
        <location filename="../defaultlook.cpp" line="631"/>
        <location filename="../defaultlook.cpp" line="650"/>
        <location filename="../defaultlook.cpp" line="659"/>
        <location filename="../defaultlook.cpp" line="706"/>
        <location filename="../defaultlook.cpp" line="714"/>
        <location filename="../defaultlook.cpp" line="741"/>
        <location filename="../defaultlook.cpp" line="744"/>
        <source>MX Tweak</source>
        <translation>MX Prilagoditve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prilagodi pano&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="159"/>
        <source>Panel</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Konfiguriraj obnašanje oken in bližnjice&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Prilagodi videz namizja&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Videz</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1878"/>
        <source>Automatic generation of fluxbox applications menu after package installation, removal, and updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2005"/>
        <source>Xfce Settings</source>
        <translation>Xfce nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="191"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vpliva na vse panoje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="266"/>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Affects 1st panel</source>
        <translation>Vpliva na prvi pano</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="383"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="388"/>
        <location filename="../defaultlook.ui" line="1619"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gumbi okna&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="221"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="226"/>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="184"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Podobno sidrišču&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="303"/>
        <location filename="../defaultlook.ui" line="363"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="167"/>
        <source>Display panel horizontally</source>
        <translation>Prikaži pano vodoravno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="241"/>
        <source>Display panel vertically</source>
        <translation>Prikaži pano navpično</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="251"/>
        <source>Restore default panel</source>
        <translation>Obnovi privzete panoje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Backup current panel configuration</source>
        <translation>Varnostno kopiraj trenutno konfiguracijo panojev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="330"/>
        <source>Restore backup panel configuration</source>
        <translation>Obnovi konfiguracijo panojev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="440"/>
        <location filename="../defaultlook.ui" line="485"/>
        <location filename="../defaultlook.ui" line="640"/>
        <location filename="../defaultlook.ui" line="965"/>
        <location filename="../defaultlook.ui" line="972"/>
        <location filename="../defaultlook.ui" line="979"/>
        <location filename="../defaultlook.ui" line="1050"/>
        <location filename="../defaultlook.ui" line="1336"/>
        <location filename="../defaultlook.ui" line="1645"/>
        <location filename="../defaultlook.ui" line="1739"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="177"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="323"/>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <source>Set Scales</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="464"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="472"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ikone&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="508"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Popravi HexChat polje za vnos v temni temi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="515"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="522"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Popravi nekatera polja spletne strani, kadar uporabljaš temno temo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="525"/>
        <source>Firefox dark theme tweak</source>
        <translation>Prilagojena temna tema za Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="532"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Upravljanik oken&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Teme&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="546"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aplikacije&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Shrani trenutne nastavitve kot tematski set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Remove User Theme Set</source>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Theme Options</source>
        <translation>Opcije za temo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="616"/>
        <source>Undo</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="626"/>
        <location filename="../defaultlook.ui" line="667"/>
        <source>Compositor</source>
        <translation>Kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="660"/>
        <source>Transparency and shadow options</source>
        <translation>Opcije za prosojnost in sence</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Uredi compton.conf neposredno v urejvalniku teksta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="677"/>
        <source>Edit compton.conf</source>
        <translation>Uredi compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Spreminjanje VBlank načina lahko pomaga pri odpravljanju težav s prikazovanjem na zaslonu (prelivanje). Glej pomoč za več podatkov.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <source>auto</source>
        <translation>samodejno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="743"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="748"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="753"/>
        <source>off</source>
        <translation>izklopljeno</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>None</source>
        <translation>brez</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="779"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="792"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastavitve za Xfce kompozitor&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="795"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Zaženi compton-conf konfiguracijsko orodje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="809"/>
        <source>Compton settings</source>
        <translation>Compton nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="823"/>
        <source>Display</source>
        <translation>Zaslon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="831"/>
        <source>Hardware Backlight</source>
        <translation>Strojna ozadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Zaslonske prilagoditve&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Izberite prikaz za xrandr prilagoditve</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="875"/>
        <source>Resolution</source>
        <translation>Ločljivost</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="882"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Shranjevanje za vsak zaslon&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="885"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="892"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="899"/>
        <location filename="../defaultlook.ui" line="996"/>
        <source>TextLabel</source>
        <translation>TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="906"/>
        <source>GTK scaling</source>
        <translation>GTK prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="926"/>
        <source>xrandr Scaling</source>
        <translation>xrandr prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <source>Config Options</source>
        <translation>Config opcije</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1095"/>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>V Thunarju ponastavi po meri določena dejanja z desnim klikom na sistemsko privzete</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1109"/>
        <source>Enable single-click on desktop</source>
        <translation>Vklopi enojni klik na namizju</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <location filename="../defaultlook.ui" line="1302"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Vklopi enojni klik v Thunar upravljalniku datotek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1130"/>
        <source>Enable Desktop Zoom </source>
        <translation>Vklopi povečavo namizja</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1088"/>
        <location filename="../defaultlook.ui" line="1708"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>V panoju prikaži okna z vseh delovnih površin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1030"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Izklopi krajšanje dolgih imen datotek na namizju</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>V odjavnem meniju omogoči hibernacijo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1081"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>opomba: za hibernacijo mora biti velikost razdelka swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1037"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Na dnu dialogov prikaži GTK File Dialog akcijske gumbe</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1137"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(za aplikacijo izklopi tudi okrasitve odjemalne strani)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1102"/>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar okno se vedno odpre v razdeljenem prikazu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1116"/>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Thunar se odpre z vodoravnim razdeljenim prikazom</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1157"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1527"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve orodne vrstice&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1180"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>On</source>
        <translation>Vklop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1185"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Off</source>
        <translation>Izklop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>On Hover</source>
        <translation>Ob prehodu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1288"/>
        <location filename="../defaultlook.ui" line="1541"/>
        <source>Autohide</source>
        <translation>Samodejno skrij</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1295"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Ponastavi VSE nastavitve mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1316"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>Placement</source>
        <translation>Postavitev</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1165"/>
        <source>Reset DefaultDock</source>
        <translation>Ponastavi PrivzetoSidrišče</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Toggle desktop icons</source>
        <translation>Preklopi prikaz namiznih ikon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1309"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Ponastavi Fluxbox meni</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1507"/>
        <location filename="../defaultlook.ui" line="1656"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ponastavitev&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;/body&gt;&lt;/p&gt;&lt;/span&gt;Nastavitve sidrišča&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1534"/>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Toggle icon captions</source>
        <translation>Preklopi prikaz oznak ikon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Namizne Ikone&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1214"/>
        <source>Height</source>
        <translation>Višina</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="198"/>
        <source>Set Tasklist plugin to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="417"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1323"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dodaj no privzete elemente menija, če kateri obstaja, obstoječemu fluxbox meniju.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1464"/>
        <source>Upgrade existing menu entries</source>
        <translation>Nadgradi obstoječe vnose menija</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1548"/>
        <source>Show Toolbar</source>
        <translation>Prikaži orodno vrstico</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1578"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <source>Systray Icon Size</source>
        <translation type="vanished">Velikost ikon v sistemski pasici</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="vanished">Privzeto</translation>
    </message>
    <message>
        <source>Small</source>
        <translation type="vanished">Majhne</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="vanished">Srednje</translation>
    </message>
    <message>
        <source>Large</source>
        <translation type="vanished">Velike</translation>
    </message>
    <message>
        <source>Larger</source>
        <translation type="vanished">Večje</translation>
    </message>
    <message>
        <source>Largest</source>
        <translation type="vanished">Največje</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1668"/>
        <source>Workspace</source>
        <translation>Delovna površina</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1675"/>
        <source>Enable single-click</source>
        <translation>Vklopi en klik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Ponastavi KDE/Plasma na privzeto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1718"/>
        <source>Other</source>
        <translation>Drugo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1764"/>
        <source>Password for administrative tasks:</source>
        <translation>Geslo za adminstracijo:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Uporabi radeon opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1785"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-radeon.conf bo varnostno kopiran v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1823"/>
        <source>&amp;User</source>
        <translation>&amp;Uporabnik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1757"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Namesto privzetega &quot;modesetting&quot; gonilnika uporabite Intel gonilnik (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1864"/>
        <source>Enable kernel sandbox</source>
        <translation>Vklopi peskovnik za jedro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-intel.conf bo varnostno kopiran v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1799"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Ponastavi Lightdm (zaslon za prijavo) na privzeto temo sistema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1843"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation>Uporabi libinput gonilnik za sledilno ploščico, namesto synaptic gonilnika za sledilno ploščico (zahteva ponoven zagon)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1778"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-amd.conf bo varnostno shranjen v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1871"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Omogoči priklop notranjih pogonov ne-korenskim uporabnikom</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Uporabi amdgpu opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1750"/>
        <source>Root</source>
        <translation>Koren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1792"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Uporabi okraske Client Side Decorations (CSD) v aplikacijah GTK3, ki jih podpirajo (zahteva ponoven zagon seje) </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1147"/>
        <source>Show percentages in notifcations when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1203"/>
        <source>Manage Tint2 Panel</source>
        <translation>Upravljaj Tint2 pano</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1806"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;zahteva ponovni zagon&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1809"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Ob zagonu vklopi Bluetooth vmesnike</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1771"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt namesti dodatne &quot;priporočene&quot; pakete kot odvisnosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1947"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1958"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1975"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1978"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1985"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="57"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display stikalo ve veljavno le za Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="140"/>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>About MX Tweak</source>
        <translation>O MX fiziranju</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="632"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplikacija za hitro spreminjanje in prilagajanje privzete teme uporabniškega vmesnika</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="635"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="636"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="660"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Končano! Firefox bo morda potreboval ponovni zagon, da bodo spremembe delovale.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>Plese remove special characters</source>
        <translation>Odstranite posebne znake</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="707"/>
        <source>from file name</source>
        <translation>iz imena datoteke</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="714"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Ime datoteke že obstaja. Izberite drugo ime</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="742"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Datoteka ni ustrezna tar.xz arhivska datoteka</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="745"/>
        <source>Archive does not contain a panel config</source>
        <translation>Arhiv ne vsebuje konfiguracije panojev</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="931"/>
        <source>Panel settings</source>
        <translation>Nastavitve panoja</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="932"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Trenutne nastavitve orodne vrstice so se shranile v skrito mapo z imenom .restore  znotraj uporabniske domace mape (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1716"/>
        <source>settings</source>
        <translation>nastavitve</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2056"/>
        <source>Choose a theme set</source>
        <translation>Izberite tematski set</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nov tematski set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Vnesite ime za nov tematski set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Gumbi oken</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Videz&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Prikaži oznake za gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Prikaži ravne gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Prikaži ročico</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Vrstni red sortiranja:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Naziv skupine in časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Naziv okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Naziv skupine in okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Brez, dovoli vlecenje in spuščanje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Obnašanje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Zbiranje oken v skupino:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Vedno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Dejanje ob kliku na srednjo tipko:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ničesar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Zapri okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Zmanjšaj okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Obnovi zmanjšano okno na trenutno delovno površino</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Nariši okvir okna, ko lebdiš nad gumbom </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Preklapljanje med okni z uporabo kolesca miške</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtriranje&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Prikaži okna z vseh delovnih površin in pogledov</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Prikaži le zmanjšana okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Prikaži okna z vseh monitorjev</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Pojavna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Okna med premikanjem</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve prosojnosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Okrasitve oken</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Prikaži sence pod zasidranimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Prikaži sence pod pojavnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Okna med spreminjanjem velikosti</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Prikaži sence pod običajnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve funkcionalnosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Prikaži predogled okna namesto ikon, kadar krožiš</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Neposredno prekrij cel zaslon z oknom </translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Neaktivna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sinhorniziraj izrisovanje z vertikalnim signalom</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Nastavitve za Xfwm kompozitor</translation>
    </message>
</context>
</TS>
